{
  Copyright (c) 1996-98, SupraSoft Ltd (SupraSoft Oy).

  SupraSoft Ltd's liability for any breach of a limited warranty is limited
  to replacement of defective diskette(s) or documentation and does not include
  or extend to claims for any other damages, including but not limited to loss
  of profits, data or use of the software, or special, incidental, or consequential
  damages or other similar claims even if SupraSoft has been specifically advised
  of the possibility of such damages.

  SUPRASOFT LTD SPECIFICALLY DISCLAIMS ALL OTHER WARRANTIES, INCLUDING BUT
  NOT LIMITED TO MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.

  Please see an accompanying license agreement file for an additional license terms.
  ------------------------------------------------------------------------------

  This unit registers the Crystal Design component to the Delphi component palette.
  Registration must be done before the component can be used at Design Time.

  To register the component, please use 'Install Component...' menu command
  to add CRYSTREG.PAS file to a component library.

  When you use the component then you may have to add following units
  to uses section of the form you have created:

  CRYSTDSG    - TCrystalDesign component itself
  CRYSTDEF    - TCDCParameterFieldInfo type and pre-defined constants
  CRYSPRNT    - ShowReportPrintDialog and ShowReportPrintSetupDialog functions.
                Use of this unit is optional 
}

unit Crystreg;

interface

{$IFDEF WIN32}
  {$R CRYST32.DCR}
{$ELSE}
  {$R CRYST16.DCR}
{$ENDIF}

uses DsgnIntf;

type
  {---- TableLogonInfo property editor ----}
  TCrystDsgServerLogonPropEdit = class(TPropertyEditor)
    function  GetAttributes: TPropertyAttributes; override;
    function  GetValue: string; override;
    procedure Edit; override;
  end;

  {---------- TCrystalAboutEdit property ------------}
  TCrystalAboutEdit = class(TComponentEditor)
  public
     procedure Edit; override;
  end;

  TCrystalAboutProperty = class(TPropertyEditor)
  public
     function  GetAttributes: TPropertyAttributes; override;
     function  GetValue: string; override;
     procedure Edit; override;
  end;

  {--- FileName property editor ----}
  TCrystalFileProperty = class(TStringProperty)
  public
     function  GetAttributes: TPropertyAttributes; override;
     procedure Edit; override;
  end;

  {---- Formulas property editor ----}
  TCrystDsgFormulaPropEdit = class(TPropertyEditor)
    function  GetAttributes: TPropertyAttributes; override;
    function  GetValue: string; override;
    procedure Edit; override;
  end;

{$IFDEF VBXCONTROL}
function ShowCrystalFileOpenDialog(options: TOpenOptions;
        const filter: string; var fileName: string): boolean;
{$ENDIF}


procedure Register;

implementation

uses Classes, SysUtils, Controls, Dialogs,
     CrystAbt, CrystFor, CrystSrv,
     CrystDsg, CrystDef;

{--------------------------------------------------------------------------
  Show fileopen dialogbox and let user to select a file name.
}
function ShowCrystalFileOpenDialog(options: TOpenOptions;
        const filter: string; var fileName: string): boolean;
var
  fileBox: TOpenDialog;
begin
  fileBox := nil;
 try
  Result  := FALSE;
  fileBox := TOpenDialog.Create(nil);
  fileBox.Options  := options;
  fileBox.Filter   := filter;
  fileBox.FileName := fileName;
  { Show dialogbox and return TRUE if OK-pressed }
  if fileBox.Execute then Result := TRUE;
  fileName := fileBox.FileName;
 finally
  fileBox.Free;
 end;
end;


{-----------------------------}
{ TCrystalDesignComponent.TableLogonInfo property editor }
function  TCrystDsgServerLogonPropEdit.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TCrystDsgServerLogonPropEdit.GetValue: string;
begin
  FmtStr(Result, '(LogonInfo %s)', [GetPropType^.Name]);
end;

procedure TCrystDsgServerLogonPropEdit.Edit;
var
  dlg: TCrystDsgServerLogon;
begin
  dlg := TCrystDsgServerLogon.Create(nil);
 try
  dlg.SetComponent(GetComponent(0) as TCrystalDesign);
  if dlg.ShowModal = mrOK then Designer.Modified;
 finally
  dlg.Free;
 end;
end;


{-----------------------------}
procedure TCrystalAboutEdit.Edit;
begin
  ShowCrystalDesignComponentAboutDialogbox;
end;


{------------------------------------------------------------------------
  About property editor. Show About dialogbox.
}
function TCrystalAboutProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TCrystalAboutProperty.GetValue: string;
begin
  Result := DBLCLICK_TEXT;
end;

procedure TCrystalAboutProperty.Edit;
begin
  ShowCrystalDesignComponentAboutDialogbox;
end;

{------------------------------------------------------------------------
  File selection property editor.
}
function TCrystalFileProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

procedure TCrystalFileProperty.Edit;
var
  fileName: string;
begin
  fileName := GetValue;
  { Show fileopen dialogbox and set the value of the property }
  if ShowCrystalFileOpenDialog([ofFileMustExist, ofHideReadOnly, ofPathMustExist],
     TXT_FILE_OPEN_FILTER, fileName) then
     SetValue(fileName);
end;


{----------------------------------------------------------}
{ Formula property editor (TCrystRep.Formulas) }
function  TCrystDsgFormulaPropEdit.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function  TCrystDsgFormulaPropEdit.GetValue: string;
begin
  FmtStr(Result, '(Formulas %s)', [GetPropType^.Name]);
end;

procedure TCrystDsgFormulaPropEdit.Edit;
var
  dlg: TCrystDsgFormulaEditDlg;
begin
  dlg := TCrystDsgFormulaEditDlg.Create(NIL);
 try
  dlg.SetComponent(GetComponent(0) as TCrystalDesign);
  if dlg.ShowModal = mrOK then Designer.Modified;
 finally
  dlg.Free;
 end;
end;


{--------------------------------------------------------------------------
  Register component and property editors.
}
procedure Register;
begin
  RegisterComponents('Supra', [TCrystalDesign]);
  RegisterComponentEditor(TCrystalDesign, TCrystalAboutEdit);
  RegisterPropertyEditor(TypeInfo(TStrings), TCrystalDesign, 'About',
                         TCrystalAboutProperty);
  RegisterPropertyEditor(TypeInfo(TStrings), TCrystalDesign, 'Formulas',
                         TCrystDsgFormulaPropEdit);
  RegisterPropertyEditor(TypeInfo(TStrings), TCrystalDesign, 'TableLogonInfo',
                         TCrystDsgServerLogonPropEdit);
  RegisterPropertyEditor(TypeInfo(String), TCrystalDesign, 'ReportName',
                         TCrystalFileProperty);
end;

end.
